/* Copyright (C) 2004-2016 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of datasid
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */
#include <string>
#include "../../include/agent/linux/datasid-common.h"

/*
 * fileExist Function
 * verify if a file exist
 */

bool fileExist(const std::string& file) {
    std::ifstream myFile(file.c_str(), std::ifstream::in);
    if (myFile.is_open()) {
        myFile.close();
        return true;
    }
    myFile.close();
    return false;
}


bool datasid_common(Conf* conf, Proxy* proxy, Agent* agent) {
    try {
        prefixIsSet(agent->getPrefix());
    } catch (const char* msg) {
        std::cout << __DATE__ << msg << std::endl;
        return false;
    }

    /* Read config file and declare only valid variables */

    if (!fileExist(agent->getDefaultConf())) {
        std::cout << __DATE__ << "ERROR: Config file not found." << std::endl;
        return false;
    } else {
       datasid_conf(agent, conf);
    }

    /* Read proxy file and declare only valid variables */

    if (!fileExist(conf->getProxyConf()))
        std::cout << __DATE__ << "WARNING: Proxy file not found. " << std::endl;
    else
        datasid_proxy(conf, proxy);

    return true;
}
