/* Copyright (C) 2004-2016 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of datasid
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */
#include <cstdlib>
#include <cstring>
#include <iostream>
#include <locale>
#include <map>
#include <sstream>
#include <string>
#include "../../include/agent/linux/datasid-conf.h"
/*
 * set Functions
 */

void Conf::setDataDir(std::string data) {
    this->dataDir = data;
}

void Conf::setLogDir(std::string log) {
    this->logDir = log;
}

void Conf::setProxyConf(std::string p) {
    this->proxyConf = p;
}

void Conf::setWebService(std::string web) {
    this->webService = web;
}

void Conf::setDelay(int d) {
    this->delay = d;
}

void Conf::setDaysToExpireLog(int d) {
    this->daysToExpireLog = d;
}

void Conf::setUpdateTries(int u) {
    this->updateTries = u;
}

void Conf::setUpdatTimeOut(int u) {
    this->updateTimeOut = u;
}

/*
 * get Functions
 */

std::string Conf::getDataDir() const {
    return  this->dataDir;
}

std::string Conf::getLogDir() const {
    return this->logDir;
}

std::string Conf::getProxyConf() const {
    return this->proxyConf;
}

std::string Conf::getWebService() const {
    return this->webService;
}

int Conf::getDelay() const {
    return this->delay;
}

int Conf::getDaysToExpireLog() const {
    return this->daysToExpireLog;
}

int Conf::getUpdateTries() const {
    return this->updateTries;
}

int Conf::getUpdateTimeOut() const {
    return this->updateTimeOut;
}

/*
 * setConf Function
 * If variables from config file setted,
 * then set the conf object
 */

bool setConf(Conf* conf, Agent* agent, std::map<std::string,
    std::string>* content) {

    if (content->count("DATADIR") == 0 ||
        content->count("LOGDIR") == 0 ||
        content->count("PROXYCONF") == 0 ||
        content->count("WEBSERVICE") == 0||
        content->count("DELAY") == 0 ||
        content->count("DAYSTOEXPIRELOG") == 0 ||
        content->count("UPDATETRIES") == 0 ||
        content->count("UPDATETIMEOUT") == 0 )
            return false;

    /* 
     * agent.getPrefix() contains the absolute path of the agent. 
     */

    std::string dataDir = agent->getPrefix() + (*content)["DATADIR"];
    std::string dataLog = agent->getPrefix() + (*content)["LOGDIR"];
    std::string proxyConf = agent->getPrefix() + (*content)["PROXYCONF"];
    std::string webService = (*content)["WEBSERVICE"];

    int delay = atoi((*content)["DELAY"].c_str());
    int daysToExpireLog = atoi((*content)["DAYSTOEXPIRELOG"].c_str());
    int updateTries = atoi((*content)["UPDATETRIES"].c_str());
    int updateTimeOut = atoi((*content)["UPDATETIMEOUT"].c_str());

    conf->setDataDir(dataDir);
    conf->setLogDir(dataLog);
    conf->setProxyConf(proxyConf);
    conf->setWebService(webService);

    conf->setDelay(delay);
    conf->setDaysToExpireLog(daysToExpireLog);
    conf->setUpdateTries(updateTries);
    conf->setUpdatTimeOut(updateTimeOut);

    return true;
}

void datasid_conf(Agent* agent, Conf* conf) {
    std::map<std::string, std::string> content;

    if (readFile(agent->getDefaultConf(), &content)) {
        if (!setConf(conf, agent, &content)) {
            std::cout << __DATE__ << " ERROR: to parse variables " <<
            "from config file." << std::endl;
            exit(1);
        }
    } else {
        std::cout << __DATE__ << " ERROR: config file not found." << std::endl;
        exit(1);
    }
}
