/* Copyright (C) 2004-2016 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of datasid
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */
#include <iostream>
#include <map>
#include <string>
#include "../../include/agent/linux/datasid-proxy.h"

/*
 * set Functions
 */

void Proxy::setHost(std::string h) {
    this->host = h;
}

void Proxy::setPort(std::string p) {
    this->port = p;
}

void Proxy::setUser(std::string u) {
    this->user = u;
}

void Proxy::setPassword(std::string p) {
    this->password = p;
}

/*
 * get Functions
 */

std::string Proxy::getHost() const {
    return this->host;
}

std::string Proxy::getPort() const {
    return this->port;
}

std::string Proxy::getUser() const {
    return this->user;
}

std::string Proxy::getPassword() const {
    return this->password;
}

/*
 * setProxy Function
 * If variables from proxy file setted,
 * then set the proxy object
 */

bool setProxy(Proxy* proxy, std::map<std::string, std::string>* content) {
    if (content->count("PROXYHOST") == 0 ||
        content->count("PROXYPORT") == 0 ||
        content->count("PROXYUSER") == 0 ||
        content->count("PROXYPASSWORD") == 0)
            return false;

    proxy->setHost((*content)["PROXYHOST"]);
    proxy->setPort((*content)["PROXYPORT"]);
    proxy->setUser((*content)["PROXYUSER"]);
    proxy->setPassword((*content)["PROXYPASSWORD"]);

    return true;
}

void datasid_proxy(Conf* conf, Proxy* proxy) {
    std::map<std::string, std::string> content;

    if (readFile(conf->getProxyConf(), &content)) {
        if (!setProxy(proxy, &content)) {
            std::cout << __DATE__ << " ERROR: to parse variables" <<
            " from proxy file." << std::endl;
            exit(1);
        }
    } else {
        std::cout << __DATE__ << " WARNING: proxy file not found." << std::endl;
    }
}
